//******************************************************************************
//
//                  LCD 16X2 (CLCD) Interface Library (Header File)
//
//******************************************************************************
//  FileName:           clcd.h
//  Compiler:           C18
//  Target Hardware:    PIC KICK Development Board
//  Company:            ENTESLA
//  website:            www.entesla.com
//  email:              feedbackATenteslaDOTcom
//
//  Author              Date            Comment
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  WebWarrior          10/04/10        Original
//  dRaGonRaCeR         13/07/10        Revision-1
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//                          Functions Overview
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  ClcdInit();
//  Initializes CLCD to 4-bit Interface. Use this function before using other 
//  CLCD functions.
//
//  ClcdSendByte(byte, type);
//  Transmits the input byte on UART.
//      type = 0 for command byte.
//	    type = 1 for data byte.
//
//  ClcdGoto(x, y);
//  Moves the cursor to a position defined by x and y
//	    x = 1 to 16 for 16 column LCD.
//	    y = 1 to 2 for 2 line LCD.
//
//  ClcdPutS(str);
//  Displays the string(str) on the CLCD.
//
//  ClcdClear();
//  Clears the contents on the CLCD.
//
//  ClcdPutCh(ch)
//  Displays the character(ch) on the CLCD.
//
//  ClcdCursorOn()
//  Turns On the Cursor on the CLCD.
//
//  ClcdCursorOff()
//  Turns Off the Cursor on the CLCD.
//
//  ClcdDisplayOff()
//  Turns Off the CLCD Display(cursor OFF, blink OFF). 
//
//  ClcdDisplayOn()
//  Turns ON the CLCD Display(cursor OFF, blink OFF)
//
//  ClcdCursorBlink()
//  Blinks the Cursor on the CLCD.
//******************************************************************************

#ifndef CLCD_H
#define CLCD_H    
 
//*****USER SETTINGS************
#define DATA_PIN            PORTD
#define DATA_PORT           LATD
#define DATA_DIR            TRISD
#define DATA_PORT_NIBBLE    UPPER_NIBBLE// Enter UPPER_NIBBLE or LOWER_NIBBLE 
										// if LCD D4-D7 lines are connected 
										// to upper or lower nibble of DATA_PORT
#define CTRL_PIN            PORTB
#define CTRL_PORT           LATB
#define CTRL_DIR            TRISB
#define CTRL_RS             2
#define CTRL_EN             4
//***End of USER SETTINGS*******    
  
//*******Public Protoype**********
#define ClcdPutCh(ch)       ClcdSendByte((ch),1)
#define ClcdCursorOn()      ClcdSendByte(0x0E,0)
#define ClcdCursorOff()     ClcdSendByte(0x0C,0)
#define ClcdDisplayOff()    ClcdSendByte(0x08,0)
#define ClcdDisplayOn()     ClcdSendByte(0x0C,0)
#define ClcdCursorBlink()   ClcdSendByte(0x0F,0)

void ClcdInit(void);
void ClcdSendByte(unsigned char byte,unsigned char type);
void ClcdGoto(unsigned char x,unsigned char y);
void ClcdPutS(void *str);
void ClcdPutS_P(const rom char *str);
void ClcdClear(void);
//*****End of Public Protoype//*****

#endif  //CLCD_H
