//******************************************************************************
//
//                  UART Interface Library (C File)
//
//******************************************************************************
//  FileName:           uart.c
//  Microcontroller:    PIC18F4520
//  Compiler:           C18
//  Target Hardware:    PIC KICK Development Board
//  Company:            ENTESLA
//  Website:            www.entesla.com
//  Email:              feedbackATenteslaDOTcom
//
//  Author              Date            Comment
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  WebWarrior          09/04/10        Original
//  dRaGoNRaCeR         27/07/10        Revision-I
//******************************************************************************
 
//*******INCLUDES*******************
#include "uart.h"
#include "config.h"
//****End of INCLUDES***************

//******************************************************************************
//  Function:   void UartInit(void)
//
//  Input:      None
//
//  Output:     None
//
//  Overview:   UART initialization.
//
//  Note:       None
//******************************************************************************
void UartInit(void)
{
    //UART pin Configuration
    TRISC = TRISC|0x40;
    TRISC = TRISC|0x80;
    SPBRG = 18;
    SPBRGH = 0;
    RCSTA = 144;
    TXSTA = 32;
    BAUDCON = 64;
}

//******************************************************************************
//  Function:   void UartPutCh(unsigned char character)
//
//  Input:      Character to Transmit
//
//  Output:     None
//
//  Overview:   Takes a character as input and transmits on UART.
//
//  Note:       None
//******************************************************************************
void UartPutCh(char character)
{
    while(!(TXSTA&0x02));   //loop till TRMT Bit is 0
    TXREG=character;        //Load data to the TXREG register (starts transmission).
}

//*********************************************************************************
//  Function:   void UartPutS(void *str)
//
//  Input:      String to Transmit
//
//  Output:     None
//
//  Overview:   Takes a string as input and transmits on UART.
//
//  Note:       Declare an array of type char in the calling function.
//              Declaration example: unsigned char msg0[8]="ENTESLA";
//			    Usage example: UartPutS(msg0);
//******************************************************************************
void UartPutS(void *str)
{
    unsigned char *str1;
    
    str1 = (unsigned char*)str;
    while(*str1)              //Check for valid character
    {
        UartPutCh(*str1++);   //Increment the address for next character
    }    
}

//******************************************************************************
//  Function:   void UartPutS_P(const rom char *string)
//
//  Input:      String(stored in program memory) to Transmit
//
//  Output:     None
//
//  Overview:   Takes a string as input and transmits on UART.
//
//  Note:       example: UartPutS_P("ENTESLA");
//******************************************************************************
void UartPutS_P(const rom char *string)
{
    while(*string)              //Check for valid character
        UartPutCh(*string++);   //Increment the address for next character
}

//******************************************************************************
//  Function:   unsigned char UartGetCh(void)
//
//  Input:      Character to Recieve
//
//  Output:     None
//
//  Overview:   Returns the recieved character.
//
//  Note:       The functions returns a character recieved in the UART data register
//******************************************************************************
unsigned char UartGetCh(void)
{    
    while(!(PIR1&0x20));    //RCIF will be set when reception is complete
        return(RCREG);      //return data in the recieve data register
}
